<template>
  <div>
    <el-table
        :data="tableData"
        :class="{tableTopLevel1: topLevel === 1, tableTopLevel2: topLevel === 2, tableTopLevel3: topLevel === 3, tableTopLevelDefault: topLevel === -1}"
        row-key="id"
        border
        max-height="510"
        @selection-change="handleSelectionChange">
      <el-table-column
          fixed
          type="selection"
          width="55">
      </el-table-column>
      <el-table-column
          fixed
          prop="roleName"
          label="角色名称"
          sortable
          width="160">
      </el-table-column>
      <el-table-column
          prop="roleKey"
          label="角色key"
          sortable
          width="120">
      </el-table-column>
      <el-table-column
          prop="status"
          label="状态"
          :formatter="statusFormtter"
          width="100">
      </el-table-column>
      <el-table-column
          prop="remark"
          label="备注"
          width="100">
      </el-table-column>
      <el-table-column
          prop="gmtCreate"
          label="创建时间"
          width="160">
      </el-table-column>
      <el-table-column
          prop="createBy"
          label="创建人"
          width="140">
      </el-table-column>
      <el-table-column
          label="操作">
        <template slot-scope="scope">
          <el-button v-if="editShow" type="primary" @click="editRole(scope.row.id)" size="mini">修改</el-button>
          <el-button v-if="permissionShow" type="primary" @click="assignPermission(scope.row.id)" size="mini">分配权限</el-button>
          <el-button v-if="delShow" type="primary" @click="deleteRole(scope.row.id)" size="mini">删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <PageC
        :top-level="topLevel"
        :handleSizeChange="handleSizeChange"
        :handleCurrentChange="handleCurrentChange"
        :pageSize="pageSize"
        :total="total"
        :currentPage="currentPage"></PageC>
    <PermissionDialog></PermissionDialog>
  </div>
</template>

<script>
import {deleteRoleById, getRoles} from "@/api/role";
import PermissionDialog from "@/components/dialog/PermissionDialog";
import PageC from "@/components/PageC";
import {Message} from "element-ui";

export default {
  name: "RoleTable",
  components: {PageC, PermissionDialog},
  data() {
    return {

    }
  },
  props: {
    topLevel: {
      required: false,
      default: -1,
      type: Number
    },
    editShow: {
      required: true,
      default: false,
      type: Boolean
    },
    delShow: {
      required: true,
      default: false,
      type: Boolean
    },
    permissionShow: {
      required: true,
      default: false,
      type: Boolean
    },
  },
  computed: {
    tableData: {
      get() {
        return this.$store.state.role.tableData;
      },
      set(value) {
        this.$store.state.role.tableData = value;
      }
    },
    // 选中行id
    multipleSelection: {
      get() {
        return this.$store.state.role.multipleSelection;
      },
      set(value) {
        this.$store.state.role.multipleSelection = value;
      }
    },
    total: {
      get() {
        return this.$store.state.role.total;
      },
      set(value) {
        this.$store.state.role.total = value;
      }
    },
    pageSize: {
      get() {
        return this.$store.state.role.pageSize;
      },
      set(value) {
        this.$store.state.role.pageSize = value;
      }
    },
    currentPage: {
      get() {
        return this.$store.state.role.currentPage;
      },
      set(value) {
        this.$store.state.role.currentPage = value;
      }
    }
  },
  methods: {
    statusFormtter(row) {
      return row.status === "0" ? "正常":"禁用"
    },
    assignPermission(roleId) {
      this.$store.dispatch("role/openTreeDialog", roleId);
    },
    handleSelectionChange(val) {
      this.multipleSelection = val.map((item) => {return item.id;})
    },
    getRoles() {
      let params = {
        currentPage: this.currentPage,
        pageSize: this.pageSize
      };
      // 刷新
      getRoles(params).then((res) => {
        this.tableData = res.data.data;
        this.total = res.data.total;
      })
    },
    editRole(id) {
      this.$store.dispatch("role/editRole", id);
    },
    deleteRole(id) {
      this.$confirm('此操作将永久删除该角色, 是否继续?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        deleteRoleById(id).then((res) => {
          Message.success(res.data.msg);
          this.getRoles();
        })
      }).catch(() => {
        this.$message({
          type: 'info',
          message: '已取消删除'
        });
      });
    },
    handleSizeChange(val) {
      this.pageSize = val;
      this.getRoles();
    },
    handleCurrentChange(val) {
      this.currentPage = val;
      this.getRoles();
    }
  },
  mounted() {
    if (this.$getButtonAuth("role:page")) {
      this.getRoles();
    }
  }
}
</script>

<style scoped>

</style>
